=========
Changelog
=========

Version 0.3.1
=============

- Fixed wrong folder name in README.md template

Version 0.3
===========

- Added a configs folder

Version 0.2.1
=============

- Fixed some docs
- Adjusted line lengths
- Some cosmetic changes

Version 0.2
===========

- Reworked the general layout some more

Version 0.1
===========

- Initial commit
